@@ -121,6 +121,7 @@ class GbpOptionParser(OptionParser):
                 'debian-branch': 'master',
                 'debian-tag': 'debian/%(version)s',
                 'debian-tag-msg': '%(pkg)s Debian release %(version)s',
+                'defuse-gitattributes': 'auto',
                 'dist': 'sid',
                 'drop': 'False',
                 'export': 'HEAD',
@@ -160,6 +161,7 @@ class GbpOptionParser(OptionParser):
                 'postedit': '',
                 'postexport': '',
                 'postimport': '',
+                'postunpack': '',
                 'posttag': '',
                 'pq-from': 'DEBIAN',
                 'prebuild': '',
@@ -180,6 +182,7 @@ class GbpOptionParser(OptionParser):
                 'submodules': 'False',
                 'symlink-orig': 'True',
                 'tarball-dir': '',
+                'upstream-signatures': 'auto',
                 'template-dir': '',
                 'time-machine': 1,
                 'track': 'True',
@@ -321,8 +324,13 @@ class GbpOptionParser(OptionParser):
         'postimport':
             "hook run after a successful import, "
             "default is '%(postimport)s'",
+        'postunpack':
+            "hook run after a unpacking the tarballs, "
+            "default is '%(postimport)s'",
         'hooks':
             "Enable running all hooks, default is %(hooks)s",
+        'upstream-signatures':
+            "Whether to import/export upstream tarball signatures",
         'time-machine':
             "don't try to apply patch queue to head commit only. "
             "Try at most TIME_MACHINE commits back, "
@@ -371,7 +379,10 @@ class GbpOptionParser(OptionParser):
         'repo-email':
             "Set repo email from the DEBFULLNAME and DEBEMAIL "
             "environment variables ('DEBIAN') or fallback to the "
-            "git configuration ('GIT'), default is '%(repo-email)s'"
+            "git configuration ('GIT'), default is '%(repo-email)s'",
+        'upstream-vcs-tag':
+            "Upstream VCS tag added to the merge commit, "
+            "default is '%(upstream-vcs-tag)s'",
     }
 
     short_opts = {
@@ -610,12 +621,17 @@ class GbpOptionParser(OptionParser):
         except KeyError:
             default = self.config[neg]
 
+        default = default.strip()
+        parts = default.split(" ", 2)
+        if len(parts) > 1 and parts[1] == '#':
+            default = parts[0]
+
         if default.lower() in ["true", "1"]:
             val = 'True'
         elif default.lower() in ["false", "0"]:
             val = 'False'
         else:
-            raise ValueError("Boolean options must be True or False")
+            raise ValueError("Boolean options must be True or False, not '%s'" % default)
         return eval(val)
 
     def get_default(self, option_name, **kwargs):
