@@ -515,7 +515,7 @@ class GitRepository(object):
         if not out:  # both branches have the same commits
             return True, True
 
-        for line in (l.decode() for l in out):
+        for line in (li.decode() for li in out):
             if line.startswith("<"):
                 has_local = True
             elif line.startswith(">"):
@@ -597,7 +597,7 @@ class GitRepository(object):
         args.add(commit)
 
         out, ret = self._git_getoutput('branch', args.args)
-        for line in [l.decode() for l in out]:
+        for line in [li.decode() for li in out]:
             # remove prefix '*' for current branch before comparing
             line = line.replace('*', '')
             if line.strip() == branch:
@@ -1069,20 +1069,24 @@ class GitRepository(object):
             raise GitRepositoryError("Not a Git repository object: '%s'" % obj)
         return out[0].decode().strip()
 
-    def list_tree(self, treeish, recurse=False, paths=None):
+    def list_tree(self, treeish, recurse=False, paths=None, sizes=False):
         """
-        Get a trees content. It returns a list of objects that match the
-        'ls-tree' output: [mode, type, sha1, path].
+        Get a trees content. It yields tuples that match the
+        'ls-tree' output: (mode, type, sha1, path). When sizes is True,
+        includes object sizes: (mode, type, sha1, size, path)
 
         @param treeish: the treeish object to list
         @type treeish: C{str}
         @param recurse: whether to list the tree recursively
         @type recurse: C{bool}
+        @param sizes: whether to include object sizes
+        @type recurse: C{bool}
         @return: the tree
         @rtype: C{list} of objects. See above.
         """
         args = GitArgs('-z')
         args.add_true(recurse, '-r')
+        args.add_true(sizes, '-l')
         args.add(treeish)
         args.add("--")
         args.add_cond(paths, paths)
@@ -1091,15 +1095,17 @@ class GitRepository(object):
         if ret:
             raise GitRepositoryError("Failed to ls-tree '%s': '%s'" % (treeish, err.decode().strip()))
 
-        tree = []
         for line in out.split(b'\0'):
             if line:
-                parts = line.split(None, 3)
+                parts = line.split(None, 4 if sizes else 3)
                 # decode everything but the file name
-                for i in range(len(parts) - 1):
-                    parts[i] = parts[i].decode()
-                tree.append(parts)
-        return tree
+                filename = parts.pop()
+                if sizes:
+                    mode, type, sha1, size = (part.decode() for part in parts)
+                    yield mode, type, sha1, int(size), filename
+                else:
+                    mode, type, sha1 = (part.decode() for part in parts)
+                    yield mode, type, sha1, filename
 
 #}
 
@@ -1113,7 +1119,7 @@ class GitRepository(object):
         """
         value, ret = self._git_getoutput('config', [name])
         if ret:
-            raise KeyError("'%s' not found in git config")
+            raise KeyError("'%s' not found in git config" % name)
         return value[0].decode()[:-1]  # first line with \n ending removed
 
     def set_config(self, name, value):
@@ -1539,7 +1545,12 @@ class GitRepository(object):
                     raise
         else:  # empty repo
             cur = None
-            branch = 'master'
+            out, _, ret = self._git_inout('symbolic-ref', ['HEAD'],
+                                          capture_stderr=True)
+            if ret:
+                raise GitRepositoryError("Currently not on a branch")
+            ref = out.decode().split('\n')[0]
+            branch = ref[len('/refs/heads'):]
 
         # Build list of parents:
         parents = []
@@ -1613,7 +1624,7 @@ class GitRepository(object):
                              merge commit
         @type first_parent: C{bool}
         """
-        args = GitArgs('--pretty=format:%H')
+        args = GitArgs('--pretty=format:%H', '--no-show-signature')
         args.add_true(num, '-%d' % num)
         args.add_true(first_parent, '--first-parent')
         if since:
@@ -1694,7 +1705,7 @@ class GitRepository(object):
         commit_sha1 = self.rev_parse("%s^0" % commitish)
         args = GitArgs('--pretty=format:%an%x00%ae%x00%ad%x00%cn%x00%ce%x00%cd%x00%s%x00%f%x00%b%x00',
                        '-z', '--date=raw', '--no-renames', '--name-status',
-                       commit_sha1)
+                       '--no-show-signature', commit_sha1)
         out, err, ret = self._git_inout('show', args.args)
         if ret:
             raise GitRepositoryError("Unable to retrieve commit info for %s"
