@@ -40,20 +40,26 @@ def orig_needs_repack(upstream_source, options):
     Determine if the upstream sources needs to be repacked
 
     We repack if
-     1. we want to filter out files and use pristine tar since we want
-        to make a filtered tarball available to pristine-tar
+     1. we want to filter out files via filters or post-unpack script and use
+        pristine tar since we want to make a filtered tarball available to
+        pristine-tar
      2. we don't have a suitable upstream tarball (e.g. zip archive or unpacked dir)
         and want to use filters
      3. we don't have a suitable upstream tarball (e.g. zip archive or unpacked dir)
         and want to use pristine-tar
+     4. we don't have a suitable upstream tarball (e.g. zip archive or unpacked dir)
+        and want to use a post-unpack script
     """
-    if ((options.pristine_tar and options.filter_pristine_tar and len(options.filters) > 0)):
+    if ((options.pristine_tar and options.filter_pristine_tar and
+       (options.filters or options.postunpack))):
         return True
     elif not upstream_source.is_orig():
         if len(options.filters):
             return True
         elif options.pristine_tar:
             return True
+        elif options.postunpack:
+            return True
     return False
 
 
@@ -68,8 +74,8 @@ def cleanup_tmp_tree(tree):
 def is_link_target(target, link):
     """does symlink link already point to target?"""
     if os.path.exists(link):
-            if os.path.samefile(target, link):
-                return True
+        if os.path.samefile(target, link):
+            return True
     return False
 
 
@@ -157,7 +163,7 @@ def download_orig(url):
         requests = None
 
     if requests is None:
-        raise GbpError("python-requests not installed")
+        raise GbpError("python3-requests not installed")
 
     tarball = os.path.basename(url)
     target = os.path.join('..', tarball)
@@ -176,4 +182,9 @@ def download_orig(url):
             os.unlink(target)
         raise GbpError("Failed to download %s: %s" % (url, e))
 
-    return DebianUpstreamSource(target)
+    sig = '{}.asc'.format(target)
+    if os.path.exists(sig):
+        gbp.log.debug("Signature {} found for {}".format(target, sig))
+    else:
+        sig = None
+    return DebianUpstreamSource(target, sig=sig)
