@@ -393,6 +393,8 @@ def build_parser(name):
     version_group.add_option("--security", dest="security", action="store_true", default=False,
                              help="Increment the Debian release number for a security upload and "
                              "add a security upload changelog comment.")
+    version_group.add_option("-l", "--local", dest="local_suffix", metavar="SUFFIX",
+                             help="Add a suffix to the Debian version number for a local build.")
     version_group.add_boolean_config_file_option(option_name="git-author", dest="use_git_author")
     commit_group.add_boolean_config_file_option(option_name="meta", dest="meta")
     commit_group.add_config_file_option(option_name="meta-closes", dest="meta_closes")
@@ -457,6 +459,12 @@ def main(argv):
 
     try:
         old_cwd = os.path.abspath(os.path.curdir)
+        for var in ['EMAIL', 'DEBEMAIL']:
+            if var in os.environ and os.environ[var]:
+                break
+        else:
+            raise GbpError("Either 'EMAIL' or 'DEBEMAIL' must be set in the environment for 'dch' to work")
+
         try:
             repo = DebianGitRepository('.', toplevel=False)
             os.chdir(repo.path)
@@ -486,7 +494,7 @@ def main(argv):
                 msg = "Continuing from commit '%s'" % since
             else:
                 msg = "Starting from first commit"
-                gbp.log.info(msg)
+            gbp.log.info(msg)
             found_snapshot_banner = has_snapshot_banner(cp)
 
         if args:
@@ -498,7 +506,7 @@ def main(argv):
         add_section = False
         # add a new changelog section if:
         if (options.new_version or options.bpo or options.nmu or options.qa or
-                options.team or options.security):
+                options.team or options.security or options.local_suffix):
             if options.bpo:
                 version_change['increment'] = '--bpo'
             elif options.nmu:
@@ -509,6 +517,8 @@ def main(argv):
                 version_change['increment'] = '--team'
             elif options.security:
                 version_change['increment'] = '--security'
+            elif options.local_suffix:
+                version_change['increment'] = '--local=%s' % options.local_suffix
             else:
                 version_change['version'] = options.new_version
             # the user wants to force a new version
